package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCert;

public interface IBisTtsaCertService {
    BisTtsaCert selectBisTtsaCertByGuid(String guid);
    List<BisTtsaCert> selectBisTtsaCertList(BisTtsaCert bisTtsaCert);
    int insertBisTtsaCert(BisTtsaCert bisTtsaCert);
    int updateBisTtsaCert(BisTtsaCert bisTtsaCert);
    int deleteBisTtsaCertByGuid(String guid);
    int deleteBisTtsaCertByGuids(String[] guids);
}
