package com.goldenwater.slaj.ttsa.controller;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.goldenwater.common.annotation.Log;
import com.goldenwater.common.core.controller.BaseController;
import com.goldenwater.common.core.domain.AjaxResult;
import com.goldenwater.common.core.page.TableDataInfo;
import com.goldenwater.common.enums.BusinessType;
import com.goldenwater.common.utils.poi.ExcelUtil;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCert;
import com.goldenwater.slaj.ttsa.service.IBisTtsaCertService;

@RestController
@RequestMapping("/ttsa/ttsacert")
public class BisTtsaCertController extends BaseController {
    @Autowired
    private IBisTtsaCertService bisTtsaCertService;

    @GetMapping("/list")
    public TableDataInfo list(BisTtsaCert bisTtsaCert) {
        startPage();
        List<BisTtsaCert> list = bisTtsaCertService.selectBisTtsaCertList(bisTtsaCert);
        return getDataTable(list);
    }

    @GetMapping("/{guid}")
    public AjaxResult getInfo(@PathVariable String guid) {
        return AjaxResult.success(bisTtsaCertService.selectBisTtsaCertByGuid(guid));
    }

    @PostMapping
    public AjaxResult add(@RequestBody BisTtsaCert bisTtsaCert) {
        return toAjax(bisTtsaCertService.insertBisTtsaCert(bisTtsaCert));
    }

    @PutMapping
    public AjaxResult edit(@RequestBody BisTtsaCert bisTtsaCert) {
        return toAjax(bisTtsaCertService.updateBisTtsaCert(bisTtsaCert));
    }

    @DeleteMapping("/{guids}")
    public AjaxResult remove(@PathVariable String[] guids) {
        return toAjax(bisTtsaCertService.deleteBisTtsaCertByGuids(guids));
    }

    @Log(title = "三类人员证书管理", businessType = BusinessType.EXPORT)
    @PreAuthorize("@ss.hasPermi('ttsa:ttsacert:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BisTtsaCert bisTtsaCert) {
        List<BisTtsaCert> list = bisTtsaCertService.selectBisTtsaCertList(bisTtsaCert);
        ExcelUtil<BisTtsaCert> util = new ExcelUtil<BisTtsaCert>(BisTtsaCert.class);
        util.exportExcel(response, list, "三类人员证书管理数据");
    }
}
